// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================


// Test flags
//<-- XCOS TEST -->
//<-- NO CHECK ERROR OUTPUT -->

//Load xcos test diagram for eci_to_ecf tests
[macros,path] = libraryinfo('xcos_aerolib');
result = importXcosDiagram(path + "../tests/unit_tests" +"/eci_to_ecf.xcos");
assert_checktrue(result);

//This diagram uses 4 variables : 
//  pos_in  : position input vectors
//  vel_in  : velocity input vectors
//  pos_out : cartesian position output vectors (to_workspace)
//  vel_out : cartesian velocity output vectors (to_workspace)

pos_in = [[3500.e3;2500.e3;5800.e3] , [4500.e3;2100.e3;6800.e3]];
vel_in = [[1.e3;3.e3;7.e3] , [2.e3;3.e3;6.e3]];
scicos_simulate(scs_m);

// Define expected values
exp_time = [0.3; 0.6; 0.9]; 
exp_pos(:,:,1) =  [ - 4273294.6,  - 4953817.2;   
                    - 488828.75,    345970.;  
                      5800000.,     6800000.];
exp_pos(:,:,2) =  [   877358.58,    1883587.8;  
                      4210729.4,    4594790.2;  
                      5800000.,     6800000.];
exp_pos(:,:,3) =  [   3722452.1,    3771221.9;  
                    - 2154843.4,  - 3230771.6;  
                      5800000.,     6800000.]; 
exp_vel(:,:,1) =  [ - 2365.1384,  - 3178.783;   
                    - 1826.9525,  - 1292.3369;  
                      7000.,        6000.];
exp_vel(:,:,2) =  [ - 992.13205,  - 229.12165;  
                      2819.0972,    3423.7843;  
                      7000.,        6000.];
exp_vel(:,:,3) =  [   2988.0404,    3322.6351;  
                      57.005278,  - 857.25822;  
                      7000.,        6000.];

//Validate results
assert_checkalmostequal(exp_time, pos_out.time, 1e-8);
assert_checkalmostequal(exp_time, vel_out.time, 1e-8);
assert_checkalmostequal(exp_pos(:,:,1), pos_out.values(:,:,1),1e-6);
assert_checkalmostequal(exp_pos(:,:,2), pos_out.values(:,:,2),1e-6);
assert_checkalmostequal(exp_pos(:,:,3), pos_out.values(:,:,3),1e-6);
assert_checkalmostequal(exp_vel(:,:,1), vel_out.values(:,:,1),1e-6);
assert_checkalmostequal(exp_vel(:,:,2), vel_out.values(:,:,2),1e-6);
assert_checkalmostequal(exp_vel(:,:,3), vel_out.values(:,:,3),1e-6);

